aboutsummaryrefslogtreecommitdiff
path: root/tests
diff options
context:
space:
mode:
authorKimplul <kimi.h.kuparinen@gmail.com>2025-02-24 21:31:46 +0200
committerKimplul <kimi.h.kuparinen@gmail.com>2025-02-24 21:31:46 +0200
commite991095180f774e3582329447c291a11499989ba (patch)
tree0708d2308a229b932a84d8ae803b31d296f9fc0f /tests
parent238116c1cf08b93335abd493df110a669786553e (diff)
downloadgran-e991095180f774e3582329447c291a11499989ba.tar.gz
gran-e991095180f774e3582329447c291a11499989ba.zip
overhaul meshes
+ Previous name was grid
Diffstat (limited to 'tests')
-rw-r--r--tests/simple_grid/sim.c134
-rw-r--r--tests/simple_grid/source.mk6
-rw-r--r--tests/simple_grid/test.c44
-rw-r--r--tests/simple_grid3d/source.mk18
-rw-r--r--tests/simple_mesh/sim.c127
-rw-r--r--tests/simple_mesh/source.mk18
-rw-r--r--tests/simple_mesh/test.c55
-rw-r--r--tests/simple_mesh3d/sim.c (renamed from tests/simple_grid3d/sim.c)50
-rw-r--r--tests/simple_mesh3d/source.mk18
-rw-r--r--tests/simple_mesh3d/test.c (renamed from tests/simple_grid3d/test.c)0
-rw-r--r--tests/starved_grid/source.mk6
-rw-r--r--tests/starved_mesh/sim.c (renamed from tests/starved_grid/sim.c)40
-rw-r--r--tests/starved_mesh/source.mk6
-rw-r--r--tests/starved_mesh/test.c (renamed from tests/starved_grid/test.c)0
14 files changed, 269 insertions, 253 deletions
diff --git a/tests/simple_grid/sim.c b/tests/simple_grid/sim.c
deleted file mode 100644
index 87250c8..0000000
--- a/tests/simple_grid/sim.c
+++ /dev/null
@@ -1,134 +0,0 @@
-/* testcase for a 64x64 grid of processors, that all just spam the first memory
- * region due to there being a 'lock' variable there, more or less the worst
- * possible program for performance. */
-#include <assert.h>
-
-#include <gran/root.h>
-#include <gran/mem/simple_mem.h>
-#include <gran/bus/simple_bus.h>
-#include <gran/uart/simple_uart.h>
-#include <gran/grid/node.h>
-#include <gran/cpu/riscv/simple_riscv64.h>
-
-unsigned char _tmp_test_bin[] = {
- 0x93, 0x96, 0x05, 0x03, 0x13, 0x18, 0x05, 0x02, 0x93, 0x86, 0x06, 0x08,
- 0xb3, 0xe6, 0x06, 0x01, 0x9b, 0x88, 0x05, 0x00, 0x63, 0x18, 0x05, 0x00,
- 0x93, 0x07, 0x20, 0x00, 0x9b, 0x88, 0x05, 0x00, 0x63, 0x84, 0xf5, 0x0c,
- 0x23, 0xb0, 0x06, 0x00, 0x1b, 0x57, 0x35, 0x00, 0xb7, 0x17, 0x00, 0x00,
- 0x13, 0x06, 0x80, 0x02, 0x13, 0x77, 0x77, 0x00, 0x23, 0x80, 0xc7, 0x00,
- 0x13, 0x07, 0x07, 0x03, 0x13, 0x76, 0x75, 0x00, 0x23, 0x80, 0xe7, 0x00,
- 0x13, 0x07, 0x06, 0x03, 0x23, 0x80, 0xe7, 0x00, 0x13, 0x06, 0xc0, 0x02,
- 0x1b, 0xd7, 0x35, 0x00, 0x23, 0x80, 0xc7, 0x00, 0x13, 0x77, 0x77, 0x00,
- 0x13, 0x06, 0x00, 0x02, 0x23, 0x80, 0xc7, 0x00, 0x13, 0x07, 0x07, 0x03,
- 0x13, 0xf6, 0x75, 0x00, 0x23, 0x80, 0xe7, 0x00, 0x13, 0x07, 0x06, 0x03,
- 0x23, 0x80, 0xe7, 0x00, 0x13, 0x07, 0x90, 0x02, 0x23, 0x80, 0xe7, 0x00,
- 0x13, 0x07, 0xa0, 0x00, 0x23, 0x80, 0xe7, 0x00, 0x93, 0x07, 0xf0, 0x00,
- 0x1b, 0x07, 0x05, 0x00, 0x63, 0x04, 0xf5, 0x02, 0x63, 0x86, 0xf8, 0x02,
- 0x9b, 0x85, 0x15, 0x00, 0x93, 0x95, 0x05, 0x03, 0x93, 0x85, 0x05, 0x08,
- 0x33, 0x68, 0xb8, 0x00, 0x93, 0x07, 0x10, 0x00, 0x23, 0x30, 0xf8, 0x00,
- 0x23, 0xb0, 0x06, 0x00, 0x67, 0x80, 0x00, 0x00, 0xe3, 0x90, 0xe8, 0xfe,
- 0x73, 0x00, 0x10, 0x00, 0x1b, 0x05, 0x15, 0x00, 0x13, 0x15, 0x05, 0x03,
- 0x13, 0x58, 0x05, 0x01, 0x93, 0x05, 0x00, 0x08, 0x33, 0x68, 0xb8, 0x00,
- 0x93, 0x07, 0x10, 0x00, 0x23, 0x30, 0xf8, 0x00, 0x23, 0xb0, 0x06, 0x00,
- 0x67, 0x80, 0x00, 0x00, 0xb7, 0x17, 0x00, 0x00, 0x13, 0x07, 0x00, 0x03,
- 0x23, 0x80, 0xe7, 0x00, 0x13, 0x07, 0xa0, 0x00, 0x23, 0x80, 0xe7, 0x00,
- 0x6f, 0xf0, 0xdf, 0xf2
-};
-unsigned int _tmp_test_bin_len = 256;
-
-static struct component *get_grid(struct component **grid, int i, int j, uint8_t x, uint8_t y)
-{
- if (i < 0)
- return NULL;
-
- if (j < 0)
- return NULL;
-
- if (i >= x)
- return NULL;
-
- if (j >= y)
- return NULL;
-
- return grid[i * x + j];
-}
-
-static stat build_grid(struct clock_domain *clk, uint8_t x, uint8_t y)
-{
- struct component **grid = calloc(x * y, sizeof(struct component *));
- assert(grid);
-
- struct component **pes = calloc(x * y, sizeof(struct component *));
- assert(pes);
-
- for (size_t i = 0; i < x; ++i)
- for (size_t j = 0; j < y; ++j) {
- struct component *node = create_grid_node(i, j);
- clock_domain_add(clk, node);
- grid[i * x + j] = node;
-
- if (i == 0 && j == 0)
- continue;
-
- if (i == 0 && j == 1)
- continue;
-
- struct component *imem = create_simple_mem(4096);
- init_simple_mem(imem, 0, _tmp_test_bin_len, _tmp_test_bin);
-
- uint64_t rcv = grid_addr(i, j, 0);
- struct component *rv64 = create_simple_riscv64(rcv, 0, imem, node);
- simple_riscv64_set_reg(rv64, 10, i); /* a0 */
- simple_riscv64_set_reg(rv64, 11, j); /* a1 */
-
- clock_domain_add(clk, rv64);
- clock_domain_add(clk, imem);
-
- pes[i * x + j] = rv64;
- }
-
- struct component *uart = create_simple_uart();
- clock_domain_add(clk, uart);
- grid_node_connect(grid[0], NULL, grid[x], grid[1], NULL, uart);
-
- struct component *dmem = create_simple_mem(4096);
- clock_domain_add(clk, dmem);
- grid_node_connect(grid[1], NULL, grid[x + 1], grid[2], grid[0], dmem);
-
- for (int i = 0; i < x; ++i)
- for (int j = 0; j < y; ++j) {
- if (i == 0 && j == 0)
- continue;
-
- if (i == 0 && j == 1)
- continue;
-
- struct component *node = grid[i * x + j];
- struct component *lower = pes[i * x + j];
- struct component *left = get_grid(grid, i - 1, j , x, y);
- struct component *right = get_grid(grid, i + 1, j , x, y);
- struct component *up = get_grid(grid, i , j + 1, x, y);
- struct component *down = get_grid(grid, i , j - 1, x, y);
- grid_node_connect(node, left, right, up, down, lower);
- }
-
- free(pes);
- free(grid);
- return OK;
-}
-
-int main()
-{
- struct clock_domain *clk = create_clock_domain(NS(1));
-
- stat r = build_grid(clk, 16, 16);
- assert(r == OK);
-
- struct gran_root *root = create_root();
- root_add_clock(root, clk);
-
- r = root_run(root);
- assert(r == OK);
-
- destroy_root(root);
-}
diff --git a/tests/simple_grid/source.mk b/tests/simple_grid/source.mk
deleted file mode 100644
index e2dd442..0000000
--- a/tests/simple_grid/source.mk
+++ /dev/null
@@ -1,6 +0,0 @@
-GRID_TEST_OBJ != ./scripts/gen-deps --sources "tests/simple_grid/sim.c"
-
-TEST_PROGS += build/tests/simple_grid/sim
-
-build/tests/simple_grid/sim: $(GRID_TEST_OBJ) $(OBJS)
- $(COMPILE) $(GRID_TEST_OBJ) $(OBJS) -o $@
diff --git a/tests/simple_grid/test.c b/tests/simple_grid/test.c
deleted file mode 100644
index 2891a6e..0000000
--- a/tests/simple_grid/test.c
+++ /dev/null
@@ -1,44 +0,0 @@
-#define X 16
-#define Y 16
-
-void _start(unsigned short x, unsigned short y)
-{
- volatile unsigned long *control = (unsigned long *)(((unsigned long)x << 32) | ((unsigned long)y << 48) + 128);
- volatile char *uart = (char *)4096;
-
- /* very hacky, not recommended but good enough for testing */
- if (x == 0 && y == 2) {
- *uart = '0';
- *uart = '\n';
- }
- else
- *control = 0; /* go to sleep */
-
- *uart = '(';
- /* [0 - 16] as two octal numbers */
- *uart = ((x >> 3) & 0x7) + '0';
- *uart = ((x >> 0) & 0x7) + '0';
-
- *uart = ',';
- *uart = ' ';
-
- *uart = ((y >> 3) & 0x7) + '0';
- *uart = ((y >> 0) & 0x7) + '0';
-
- *uart = ')';
- *uart = '\n';
-
- if (x == 15 && y == 15)
- asm ("ebreak\n");
-
- if (y == 15) {
- x++;
- y = 0;
- }
- else
- y++;
-
- volatile unsigned long *next = (unsigned long *)(((unsigned long)x << 32) | ((unsigned long)y << 48) + 128);
- *next = 1; /* wake next core */
- *control = 0; /* go to sleep again */
-}
diff --git a/tests/simple_grid3d/source.mk b/tests/simple_grid3d/source.mk
deleted file mode 100644
index 4c19568..0000000
--- a/tests/simple_grid3d/source.mk
+++ /dev/null
@@ -1,18 +0,0 @@
-GRID3D_TEST_OBJ != ./scripts/gen-deps --sources "tests/simple_grid3d/sim.c"
-TEST_PROGS += build/tests/simple_grid3d/sim
-
-build/tests/simple_grid3d/test.inc: tests/simple_grid3d/test.c
- riscv64-unknown-elf-gcc -O2 -Wall -Wextra -ffreestanding -nostdlib \
- -march=rv64i -mabi=lp64 \
- -o build/tests/simple_grid3d/test \
- tests/simple_grid3d/test.c
- riscv64-unknown-elf-objcopy -Obinary \
- build/tests/simple_grid3d/test \
- build/tests/simple_grid3d/test.bin
- xxd -i build/tests/simple_grid3d/test.bin \
- > build/tests/simple_grid3d/test.inc
-
-build/tests/simple_grid3d/sim.o: build/tests/simple_grid3d/test.inc
-
-build/tests/simple_grid3d/sim: $(GRID3D_TEST_OBJ) $(OBJS)
- $(COMPILE) $(GRID3D_TEST_OBJ) $(OBJS) -o $@
diff --git a/tests/simple_mesh/sim.c b/tests/simple_mesh/sim.c
new file mode 100644
index 0000000..c3cdc33
--- /dev/null
+++ b/tests/simple_mesh/sim.c
@@ -0,0 +1,127 @@
+#include <assert.h>
+
+#include <gran/root.h>
+#include <gran/mem/simple_mem.h>
+#include <gran/bus/simple_bus.h>
+#include <gran/uart/simple_uart.h>
+#include <gran/mesh/node.h>
+#include <gran/cpu/riscv/simple_riscv64.h>
+
+#include "../build/tests/simple_mesh/test.inc"
+
+static size_t idx_1d(int x, int y, uint8_t xw, uint8_t yw)
+{
+ (void)xw; /* maybe unused */
+ assert(0 <= x && x < xw);
+ assert(0 <= y && y < yw);
+ return (x * yw) + y;
+}
+
+static struct component *mesh_at(struct component **mesh,
+ int x, int y,
+ uint8_t xw, uint8_t yw)
+{
+ if (x < 0)
+ return NULL;
+
+ if (y < 0)
+ return NULL;
+
+ if (x >= xw)
+ return NULL;
+
+ if (y >= yw)
+ return NULL;
+
+ return mesh[idx_1d(x, y, xw, yw)];
+}
+
+static void connect_mesh(struct component **mesh, struct component *c,
+ uint16_t x, uint16_t y,
+ uint16_t xw, uint16_t yw)
+{
+ mesh_node_connect(mesh_at(mesh, x, y, xw, yw),
+ mesh_at(mesh, x , y+1, xw, yw),
+ mesh_at(mesh, x , y-1, xw, yw),
+ mesh_at(mesh, x+1, y , xw, yw),
+ mesh_at(mesh, x-1, y , xw, yw),
+ c);
+}
+
+static stat build_mesh(struct clock_domain *clk, uint16_t x, uint16_t y)
+{
+ struct component **mesh = calloc(x * y, sizeof(struct component *));
+ assert(mesh);
+
+ struct component **pes = calloc(x * y, sizeof(struct component *));
+ assert(pes);
+
+ for (size_t i = 0; i < x; ++i)
+ for (size_t j = 0; j < y; ++j) {
+ struct component *node = create_mesh_node(i, j);
+ clock_domain_add(clk, node);
+ mesh[idx_1d(i, j, x, y)] = node;
+
+ if (i == 0 && j == 0)
+ continue;
+
+ if (i == 0 && j == 1)
+ continue;
+
+ struct component *imem = create_simple_mem(4096);
+ init_simple_mem(imem, 0,
+ build_tests_simple_mesh_test_bin_len,
+ build_tests_simple_mesh_test_bin);
+
+ uint64_t rcv = mesh_addr(i, j, 0);
+ struct component *rv64 = create_simple_riscv64(rcv, 0, imem, node);
+ simple_riscv64_set_reg(rv64, 10, i); /* a0 */
+ simple_riscv64_set_reg(rv64, 11, j); /* a1 */
+ simple_riscv64_set_reg(rv64, 12, x); /* a3 */
+ simple_riscv64_set_reg(rv64, 13, y); /* a4 */
+
+ clock_domain_add(clk, rv64);
+ clock_domain_add(clk, imem);
+
+ pes[idx_1d(i, j, x, y)] = rv64;
+ }
+
+ struct component *uart = create_simple_uart();
+ clock_domain_add(clk, uart);
+ connect_mesh(mesh, uart, 0, 0, x, y);
+
+ struct component *dmem = create_simple_mem(4096);
+ clock_domain_add(clk, dmem);
+ connect_mesh(mesh, dmem, 0, 1, x, y);
+
+ for (int i = 0; i < x; ++i)
+ for (int j = 0; j < y; ++j) {
+ if (i == 0 && j == 0)
+ continue;
+
+ if (i == 0 && j == 1)
+ continue;
+
+ connect_mesh(mesh, pes[idx_1d(i, j, x, y)], i, j, x, y);
+ }
+
+ free(mesh);
+ free(pes);
+ return OK;
+}
+
+int main()
+{
+ struct clock_domain *clk = create_clock_domain(NS(1));
+
+ stat r = build_mesh(clk, 8, 8);
+ assert(r == OK);
+
+ struct gran_root *root = create_root();
+ root_add_clock(root, clk);
+
+ r = root_run(root);
+ assert(r == OK);
+
+ destroy_root(root);
+}
diff --git a/tests/simple_mesh/source.mk b/tests/simple_mesh/source.mk
new file mode 100644
index 0000000..748e252
--- /dev/null
+++ b/tests/simple_mesh/source.mk
@@ -0,0 +1,18 @@
+MESH_TEST_OBJ != ./scripts/gen-deps --sources "tests/simple_mesh/sim.c"
+TEST_PROGS += build/tests/simple_mesh/sim
+
+build/tests/simple_mesh/test.inc: tests/simple_mesh/test.c
+ riscv64-unknown-elf-gcc -O2 -Wall -Wextra -ffreestanding -nostdlib \
+ -march=rv64i -mabi=lp64 \
+ -o build/tests/simple_mesh/test \
+ tests/simple_mesh/test.c
+ riscv64-unknown-elf-objcopy -Obinary \
+ build/tests/simple_mesh/test \
+ build/tests/simple_mesh/test.bin
+ xxd -i build/tests/simple_mesh/test.bin \
+ > build/tests/simple_mesh/test.inc
+
+build/tests/simple_mesh/sim.o: build/tests/simple_mesh/test.inc
+
+build/tests/simple_mesh/sim: $(MESH_TEST_OBJ) $(OBJS)
+ $(COMPILE) $(MESH_TEST_OBJ) $(OBJS) -o $@
diff --git a/tests/simple_mesh/test.c b/tests/simple_mesh/test.c
new file mode 100644
index 0000000..b1bbe84
--- /dev/null
+++ b/tests/simple_mesh/test.c
@@ -0,0 +1,55 @@
+__attribute__((always_inline))
+static inline void print_int8(volatile char *uart, unsigned x)
+{
+ *uart = ((x >> 4) & 0xf) + '0';
+ *uart = ((x >> 0) & 0xf) + '0';
+}
+
+__attribute__((always_inline))
+static inline void print_addr(volatile char *uart, unsigned x, unsigned y)
+{
+ *uart = '(';
+ print_int8(uart, x);
+ *uart = ',';
+ *uart = ' ';
+ print_int8(uart, y);
+ *uart = ')';
+ *uart = '\n';
+}
+
+__attribute__((always_inline))
+static inline unsigned wrap(unsigned x, unsigned X)
+{
+ return x + 1 >= X ? 0 : x + 1;
+}
+
+__attribute__((always_inline))
+static inline unsigned next_idx(unsigned x, unsigned y, unsigned X, unsigned Y)
+{
+ unsigned yi = wrap(y, Y);
+ unsigned xi = yi < y ? wrap(x, X) : x;
+
+ return (xi << 16) | yi;
+}
+
+void _start(unsigned x, unsigned y, unsigned X, unsigned Y)
+{
+ volatile char *uart = (char *)4096;
+ volatile unsigned *control = (unsigned *)(1ULL << 48);
+
+ if (x == 0 && y == 2) {
+ goto do_work;
+ } else {
+ while (*control != ((x << 16) | y)) {}
+ }
+
+do_work:
+ print_addr(uart, x, y);
+ *control = next_idx(x, y, X, Y);
+
+ if (x == X - 1 && y == Y - 1)
+ asm("ebreak");
+
+ /* otherwise just loop */
+ while (1) {}
+}
diff --git a/tests/simple_grid3d/sim.c b/tests/simple_mesh3d/sim.c
index 6df29dd..9557d83 100644
--- a/tests/simple_grid3d/sim.c
+++ b/tests/simple_mesh3d/sim.c
@@ -4,10 +4,10 @@
#include <gran/mem/simple_mem.h>
#include <gran/bus/simple_bus.h>
#include <gran/uart/simple_uart.h>
-#include <gran/grid/node3d.h>
+#include <gran/mesh/node3d.h>
#include <gran/cpu/riscv/simple_riscv64.h>
-#include "../build/tests/simple_grid3d/test.inc"
+#include "../build/tests/simple_mesh3d/test.inc"
static size_t idx_1d(int x, int y, int z, uint8_t xw, uint8_t yw, uint8_t zw)
{
@@ -18,7 +18,7 @@ static size_t idx_1d(int x, int y, int z, uint8_t xw, uint8_t yw, uint8_t zw)
return (x * yw * zw) + (y * zw) + z;
}
-static struct component *grid_at(struct component **grid,
+static struct component *mesh_at(struct component **mesh,
int x, int y, int z,
uint8_t xw, uint8_t yw, uint8_t zw)
{
@@ -40,27 +40,27 @@ static struct component *grid_at(struct component **grid,
if (z >= zw)
return NULL;
- return grid[idx_1d(x, y, z, xw, yw, zw)];
+ return mesh[idx_1d(x, y, z, xw, yw, zw)];
}
-static void connect_grid3d(struct component **grid, struct component *c,
+static void connect_mesh3d(struct component **mesh, struct component *c,
uint8_t x, uint8_t y, uint8_t z,
uint8_t xw, uint8_t yw, uint8_t zw)
{
- grid_node3d_connect(grid_at(grid, x, y, z, xw, yw, zw),
- grid_at(grid, x , y+1, z , xw, yw, zw),
- grid_at(grid, x , y-1, z , xw, yw, zw),
- grid_at(grid, x-1, y , z , xw, yw, zw),
- grid_at(grid, x+1, y , z , xw, yw, zw),
- grid_at(grid, x , y , z+1, xw, yw, zw),
- grid_at(grid, x , y , z-1, xw, yw, zw),
+ mesh_node3d_connect(mesh_at(mesh, x, y, z, xw, yw, zw),
+ mesh_at(mesh, x , y+1, z , xw, yw, zw),
+ mesh_at(mesh, x , y-1, z , xw, yw, zw),
+ mesh_at(mesh, x+1, y , z , xw, yw, zw),
+ mesh_at(mesh, x-1, y , z , xw, yw, zw),
+ mesh_at(mesh, x , y , z+1, xw, yw, zw),
+ mesh_at(mesh, x , y , z-1, xw, yw, zw),
c);
}
-static stat build_torus3d(struct clock_domain *clk, uint8_t x, uint8_t y, uint8_t z)
+static stat build_mesh3d(struct clock_domain *clk, uint8_t x, uint8_t y, uint8_t z)
{
- struct component **grid = calloc(x * y * z, sizeof(struct component *));
- assert(grid);
+ struct component **mesh = calloc(x * y * z, sizeof(struct component *));
+ assert(mesh);
struct component **pes = calloc(x * y * z, sizeof(struct component *));
assert(pes);
@@ -68,9 +68,9 @@ static stat build_torus3d(struct clock_domain *clk, uint8_t x, uint8_t y, uint8_
for (size_t i = 0; i < x; ++i)
for (size_t j = 0; j < y; ++j)
for (size_t k = 0; k < z; ++k) {
- struct component *node = create_grid_node3d(i, j, k);
+ struct component *node = create_mesh_node3d(i, j, k);
clock_domain_add(clk, node);
- grid[idx_1d(i, j, k, x, y, z)] = node;
+ mesh[idx_1d(i, j, k, x, y, z)] = node;
if (i == 0 && j == 0 && k == 0)
continue;
@@ -80,10 +80,10 @@ static stat build_torus3d(struct clock_domain *clk, uint8_t x, uint8_t y, uint8_
struct component *imem = create_simple_mem(4096);
init_simple_mem(imem, 0,
- build_tests_simple_grid3d_test_bin_len,
- build_tests_simple_grid3d_test_bin);
+ build_tests_simple_mesh3d_test_bin_len,
+ build_tests_simple_mesh3d_test_bin);
- uint64_t rcv = grid3d_addr(i, j, k, 0);
+ uint64_t rcv = mesh3d_addr(i, j, k, 0);
struct component *rv64 = create_simple_riscv64(rcv, 0, imem, node);
simple_riscv64_set_reg(rv64, 10, i); /* a0 */
simple_riscv64_set_reg(rv64, 11, j); /* a1 */
@@ -100,11 +100,11 @@ static stat build_torus3d(struct clock_domain *clk, uint8_t x, uint8_t y, uint8_
struct component *uart = create_simple_uart();
clock_domain_add(clk, uart);
- connect_grid3d(grid, uart, 0, 0, 0, x, y, z);
+ connect_mesh3d(mesh, uart, 0, 0, 0, x, y, z);
struct component *dmem = create_simple_mem(4096);
clock_domain_add(clk, dmem);
- connect_grid3d(grid, dmem, 0, 0, 1, x, y, z);
+ connect_mesh3d(mesh, dmem, 0, 0, 1, x, y, z);
for (int i = 0; i < x; ++i)
for (int j = 0; j < y; ++j)
@@ -115,12 +115,12 @@ static stat build_torus3d(struct clock_domain *clk, uint8_t x, uint8_t y, uint8_
if (i == 0 && j == 0 && k == 1)
continue;
- connect_grid3d(grid,
+ connect_mesh3d(mesh,
pes[idx_1d(i, j, k, x, y, z)],
i, j, k, x, y, z);
}
- free(grid);
+ free(mesh);
free(pes);
return OK;
}
@@ -129,7 +129,7 @@ int main()
{
struct clock_domain *clk = create_clock_domain(NS(1));
- stat r = build_torus3d(clk, 4, 4, 4);
+ stat r = build_mesh3d(clk, 4, 4, 4);
assert(r == OK);
struct gran_root *root = create_root();
diff --git a/tests/simple_mesh3d/source.mk b/tests/simple_mesh3d/source.mk
new file mode 100644
index 0000000..30aea2c
--- /dev/null
+++ b/tests/simple_mesh3d/source.mk
@@ -0,0 +1,18 @@
+MESH3D_TEST_OBJ != ./scripts/gen-deps --sources "tests/simple_mesh3d/sim.c"
+TEST_PROGS += build/tests/simple_mesh3d/sim
+
+build/tests/simple_mesh3d/test.inc: tests/simple_mesh3d/test.c
+ riscv64-unknown-elf-gcc -O2 -Wall -Wextra -ffreestanding -nostdlib \
+ -march=rv64i -mabi=lp64 \
+ -o build/tests/simple_mesh3d/test \
+ tests/simple_mesh3d/test.c
+ riscv64-unknown-elf-objcopy -Obinary \
+ build/tests/simple_mesh3d/test \
+ build/tests/simple_mesh3d/test.bin
+ xxd -i build/tests/simple_mesh3d/test.bin \
+ > build/tests/simple_mesh3d/test.inc
+
+build/tests/simple_mesh3d/sim.o: build/tests/simple_mesh3d/test.inc
+
+build/tests/simple_mesh3d/sim: $(MESH3D_TEST_OBJ) $(OBJS)
+ $(COMPILE) $(MESH3D_TEST_OBJ) $(OBJS) -o $@
diff --git a/tests/simple_grid3d/test.c b/tests/simple_mesh3d/test.c
index 2953d41..2953d41 100644
--- a/tests/simple_grid3d/test.c
+++ b/tests/simple_mesh3d/test.c
diff --git a/tests/starved_grid/source.mk b/tests/starved_grid/source.mk
deleted file mode 100644
index 428435f..0000000
--- a/tests/starved_grid/source.mk
+++ /dev/null
@@ -1,6 +0,0 @@
-STARVED_TEST_OBJ != ./scripts/gen-deps --sources "tests/starved_grid/sim.c"
-
-TEST_PROGS += build/tests/starved_grid/sim
-
-build/tests/starved_grid/sim: $(STARVED_TEST_OBJ) $(OBJS)
- $(COMPILE) $(STARVED_TEST_OBJ) $(OBJS) -o $@
diff --git a/tests/starved_mesh/source.mk b/tests/starved_mesh/source.mk
new file mode 100644
index 0000000..2d3a6e8
--- /dev/null
+++ b/tests/starved_mesh/source.mk
@@ -0,0 +1,6 @@
+STARVED_TEST_OBJ != ./scripts/gen-deps --sources "tests/starved_mesh/sim.c"
+
+TEST_PROGS += build/tests/starved_mesh/sim
+
+build/tests/starved_mesh/sim: $(STARVED_TEST_OBJ) $(OBJS)
+ $(COMPILE) $(STARVED_TEST_OBJ) $(OBJS) -o $@
diff --git a/tests/starved_grid/test.c b/tests/starved_mesh/test.c
index c91868c..c91868c 100644
--- a/tests/starved_grid/test.c
+++ b/tests/starved_mesh/test.c
diff --git a/tests/starved_grid/sim.c b/tests/starved_mesh/sim.c
index d858917..1967e0b 100644
--- a/tests/starved_grid/sim.c
+++ b/tests/starved_mesh/sim.c
@@ -1,4 +1,4 @@
/* testcase for a 64x64 grid of processors, that all just spam the first memory
* region due to there being a 'lock' variable there, more or less the worst
* possible program for performance. */
#include <assert.h>
@@ -7,7 +7,7 @@
#include <gran/mem/simple_mem.h>
#include <gran/bus/simple_bus.h>
#include <gran/uart/simple_uart.h>
-#include <gran/grid/node.h>
+#include <gran/mesh/node.h>
#include <gran/cpu/riscv/simple_riscv64.h>
unsigned char _tmp_test_bin[] = {
@@ -36,7 +36,7 @@ unsigned char _tmp_test_bin[] = {
};
unsigned int _tmp_test_bin_len = 260;
-static struct component *get_grid(struct component **grid, int i, int j, uint8_t x, uint8_t y)
+static struct component *get_mesh(struct component **mesh, int i, int j, uint8_t x, uint8_t y)
{
if (i < 0)
return NULL;
@@ -50,22 +50,22 @@ static struct component *get_grid(struct component **grid, int i, int j, uint8_t
if (j >= y)
return NULL;
- return grid[i * x + j];
+ return mesh[i * x + j];
}
-static stat build_grid(struct clock_domain *clk, uint8_t x, uint8_t y)
+static stat build_mesh(struct clock_domain *clk, uint8_t x, uint8_t y)
{
- struct component **grid = calloc(x * y, sizeof(struct component *));
- assert(grid);
+ struct component **mesh = calloc(x * y, sizeof(struct component *));
+ assert(mesh);
struct component **pes = calloc(x * y, sizeof(struct component *));
assert(pes);
for (size_t i = 0; i < x; ++i)
for (size_t j = 0; j < y; ++j) {
- struct component *node = create_grid_node(i, j);
+ struct component *node = create_mesh_node(i, j);
clock_domain_add(clk, node);
- grid[i * x + j] = node;
+ mesh[i * x + j] = node;
if (i == 0 && j == 0)
continue;
@@ -76,7 +76,7 @@ static stat build_grid(struct clock_domain *clk, uint8_t x, uint8_t y)
struct component *imem = create_simple_mem(4096);
init_simple_mem(imem, 0, _tmp_test_bin_len, _tmp_test_bin);
- uint64_t rcv = grid_addr(i, j, 0);
+ uint64_t rcv = mesh_addr(i, j, 0);
struct component *rv64 = create_simple_riscv64(rcv, 0, imem, node);
simple_riscv64_set_reg(rv64, 10, i); /* a0 */
simple_riscv64_set_reg(rv64, 11, j); /* a1 */
@@ -89,11 +89,11 @@ static stat build_grid(struct clock_domain *clk, uint8_t x, uint8_t y)
struct component *uart = create_simple_uart();
clock_domain_add(clk, uart);
- grid_node_connect(grid[0], NULL, grid[x], grid[1], NULL, uart);
+ mesh_node_connect(mesh[0], NULL, mesh[x], mesh[1], NULL, uart);
struct component *dmem = create_simple_mem(4096);
clock_domain_add(clk, dmem);
- grid_node_connect(grid[1], NULL, grid[x + 1], grid[2], grid[0], dmem);
+ mesh_node_connect(mesh[1], NULL, mesh[x + 1], mesh[2], mesh[0], dmem);
for (int i = 0; i < x; ++i)
for (int j = 0; j < y; ++j) {
@@ -103,17 +103,17 @@ static stat build_grid(struct clock_domain *clk, uint8_t x, uint8_t y)
if (i == 0 && j == 1)
continue;
- struct component *node = grid[i * x + j];
+ struct component *node = mesh[i * x + j];
struct component *lower = pes[i * x + j];
- struct component *left = get_grid(grid, i - 1, j , x, y);
- struct component *right = get_grid(grid, i + 1, j , x, y);
- struct component *up = get_grid(grid, i , j + 1, x, y);
- struct component *down = get_grid(grid, i , j - 1, x, y);
- grid_node_connect(node, left, right, up, down, lower);
+ struct component *left = get_mesh(mesh, i - 1, j , x, y);
+ struct component *right = get_mesh(mesh, i + 1, j , x, y);
+ struct component *up = get_mesh(mesh, i , j + 1, x, y);
+ struct component *down = get_mesh(mesh, i , j - 1, x, y);
+ mesh_node_connect(node, left, right, up, down, lower);
}
free(pes);
- free(grid);
+ free(mesh);
return OK;
}
@@ -121,7 +121,7 @@ int main()
{
struct clock_domain *clk = create_clock_domain(NS(1));
- stat r = build_grid(clk, 16, 16);
+ stat r = build_mesh(clk, 16, 16);
assert(r == OK);
struct gran_root *root = create_root();
@@ -1,4 +1,4 @@
-/* testcase for a 64x64 grid of processors, that all just spam the first memory
+/* testcase for a 64x64 mesh of processors, that all just spam the first memory
* region due to there being a 'lock' variable there, more or less the worst
* possible program for performance. */